@@ -6,9 +6,8 @@ package Dancer2::Plugin::Adapter;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Wrap any simple class as a service for Dancer2
 # VERSION
-$Dancer2::Plugin::Adapter::VERSION = '0.006';
+$Dancer2::Plugin::Adapter::VERSION = '0.007';
 use Dancer2::Plugin;
-use Dancer2;
 use Class::Load qw/try_load_class/;
 
 my %singletons;
@@ -19,9 +18,9 @@ my %save_by_scope = (
   singleton => sub { $singletons{ $_[1] } = $_[2] },
   request   => sub {
     my $dsl = shift;
-    my $hr = $dsl->var("_dpa") || {};
+    my $hr = $dsl->app->request->var("_dpa") || {};
     $hr->{ $_[0] } = $_[1];
-    $dsl->var( "_dpa", $hr );
+    $dsl->app->request->var( "_dpa", $hr );
   },
   none      => sub { },
 );
@@ -29,12 +28,12 @@ my %save_by_scope = (
 # called with ($dsl, $name)
 my %fetch_by_scope = (
   singleton => sub { $singletons{ $_[1] } },
-  request   => sub { my $hr = $_[0]->var("_dpa") || {}; $hr->{ $_[1] }; },
+  request   => sub { my $hr = $_[0]->app->request->var("_dpa") || {}; $hr->{ $_[1] }; },
   none      => sub { },
 );
 
 register service => sub {
-  my ( $dsl, $name ) = plugin_args(@_);
+  my ( $dsl, $name ) = @_;
 
   unless ($name) {
     die "Dancer2::Plugin::Adapter::service() requires a name argument";
@@ -99,7 +98,7 @@ Dancer2::Plugin::Adapter - Wrap any simple class as a service for Dancer2
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -257,10 +256,20 @@ future use based on its C<scope> configuration option.
 
 Thank you to Matt S. Trout for suggesting the 'scope' controls.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 David Golden <dagolden@cpan.org>
 
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2012 by David Golden.
